@@ -5,6 +5,7 @@
 namespace Icinga\Module\X509\Controllers;
 
 use Icinga\Exception\ConfigurationError;
+use Icinga\Module\X509\Common\Database;
 use Icinga\Module\X509\Controller;
 use Icinga\Module\X509\Model\X509Certificate;
 use Icinga\Module\X509\UsageTable;
@@ -22,7 +23,7 @@ class UsageController extends Controller
         $this->getTabs()->enableDataExports();
 
         try {
-            $conn = $this->getDb();
+            $conn = Database::get();
         } catch (ConfigurationError $_) {
             $this->render('missing-resource', null, true);
             return;
@@ -94,6 +95,7 @@ class UsageController extends Controller
         $this->addControl($searchBar);
 
         $this->handleFormatRequest($targets, function (Query $targets) {
+            /** @var X509Certificate $usage */
             foreach ($targets as $usage) {
                 $usage->valid_from = $usage->valid_from->format('l F jS, Y H:i:s e');
                 $usage->valid_to = $usage->valid_to->format('l F jS, Y H:i:s e');
@@ -128,7 +130,7 @@ class UsageController extends Controller
 
     public function searchEditorAction()
     {
-        $editor = $this->createSearchEditor(X509Certificate::on($this->getDb()), [
+        $editor = $this->createSearchEditor(X509Certificate::on(Database::get()), [
             LimitControl::DEFAULT_LIMIT_PARAM,
             SortControl::DEFAULT_SORT_PARAM
         ]);
