@@ -8,6 +8,7 @@ use DateTime;
 use Icinga\Module\X509\Model\X509Certificate;
 use ipl\Html\BaseHtmlElement;
 use ipl\Html\Html;
+use ipl\Web\Widget\IcingaIcon;
 
 /**
  * Widget to display X.509 certificate details
@@ -37,11 +38,20 @@ class CertificateDetails extends BaseHtmlElement
 //        $pubkey = openssl_pkey_get_details(openssl_get_publickey($pem));
 
         $subject = Html::tag('dl');
-        foreach ($cert['subject'] as $key => $value) {
-            $subject->add([
-                Html::tag('dt', $key),
-                Html::tag('dd', $value)
-            ]);
+        $sans = CertificateUtils::splitSANs($cert['extensions']['subjectAltName'] ?? null);
+        if (! isset($cert['subject']['CN']) && ! empty($sans)) {
+            foreach ($sans as $type => $values) {
+                foreach ($values as $value) {
+                    $subject->addHtml(Html::tag('dt', $type), Html::tag('dd', $value));
+                }
+            }
+        } else {
+            foreach ($cert['subject'] as $key => $value) {
+                $subject->add([
+                    Html::tag('dt', $key),
+                    Html::tag('dd', $value)
+                ]);
+            }
         }
 
         $issuer = Html::tag('dl');
@@ -92,7 +102,7 @@ class CertificateDetails extends BaseHtmlElement
         ]);
 
         $this->add([
-            Html::tag('h2', [Html::tag('i', ['class' => 'x509-icon-cert']), $this->cert->subject]),
+            Html::tag('h2', [new IcingaIcon('certificate'), $this->cert->subject]),
             Html::tag('h3', mt('x509', 'Subject Name')),
             $subject,
             Html::tag('h3', mt('x509', 'Issuer Name')),
