@@ -8,14 +8,17 @@ use Exception;
 use Icinga\Application\Logger;
 use Icinga\File\Storage\TemporaryLocalFileStorage;
 use Icinga\Module\X509\Model\X509Certificate;
-use Icinga\Module\X509\Model\X509CertificateChain;
 use Icinga\Module\X509\Model\X509CertificateSubjectAltName;
 use Icinga\Module\X509\Model\X509Dn;
 use Icinga\Module\X509\Model\X509Target;
+use ipl\Orm\Model;
 use ipl\Sql\Connection;
 use ipl\Sql\Expression;
 use ipl\Sql\Select;
 use ipl\Stdlib\Filter;
+use ipl\Stdlib\Str;
+
+use function ipl\Stdlib\yield_groups;
 
 class CertificateUtils
 {
@@ -123,15 +126,14 @@ class CertificateUtils
      *
      * If the given DN contains a CN, the CN is returned. Else, the DN is returned as string.
      *
-     * @param   array   $dn
+     * @param array $dn
      *
      * @return  string  The CN if it exists or the full DN as string
      */
-    private static function shortNameFromDN(array $dn)
+    private static function shortNameFromDN(array $dn): string
     {
         if (isset($dn['CN'])) {
-            $cn = (array) $dn['CN'];
-            return $cn[0];
+            return ((array) $dn['CN'])[0];
         } else {
             $result = [];
             foreach ($dn as $key => $value) {
@@ -151,17 +153,29 @@ class CertificateUtils
     /**
      * Split the given Subject Alternative Names into key-value pairs
      *
-     * @param   string  $sans
+     * @param ?string $sanStr
      *
-     * @return  \Generator
+     * @return  array
      */
-    private static function splitSANs($sans)
+    public static function splitSANs(?string $sanStr): array
     {
-        preg_match_all('/(?:^|, )([^:]+):/', $sans, $keys);
-        $values = preg_split('/(^|, )[^:]+:\s*/', $sans);
-        for ($i = 0; $i < count($keys[1]); $i++) {
-            yield [$keys[1][$i], $values[$i + 1]];
+        $sans = [];
+        foreach (Str::trimSplit($sanStr) as $altName) {
+            if (strpos($altName, ':') === false) {
+                [$k, $v] = Str::trimSplit($altName, '=', 2);
+            } else {
+                [$k, $v] = Str::trimSplit($altName, ':', 2);
+            }
+
+            $sans[$k][] = $v;
         }
+
+        $order = array_flip(['DNS', 'URI', 'IP Address', 'email', 'DirName']);
+        uksort($sans, function ($a, $b) use ($order) {
+            return ($order[$a] ?? PHP_INT_MAX) <=> ($order[$b] ?? PHP_INT_MAX);
+        });
+
+        return $sans;
     }
 
     /**
@@ -232,11 +246,18 @@ class CertificateUtils
         $pubkey = openssl_pkey_get_details(openssl_pkey_get_public($cert));
         $signature = explode('-', $certInfo['signatureTypeSN']);
 
+        $sans = static::splitSANs($certInfo['extensions']['subjectAltName'] ?? null);
+        if (! isset($certInfo['subject']['CN']) && ! empty($sans)) {
+            $subject = current($sans)[0];
+        } else {
+            $subject = self::shortNameFromDN($certInfo['subject']);
+        }
+
         // TODO: https://github.com/Icinga/ipl-orm/pull/78
         $db->insert(
             'x509_certificate',
             [
-                'subject'             => CertificateUtils::shortNameFromDN($certInfo['subject']),
+                'subject'             => $subject,
                 'subject_hash'        => $dbTool->marshalBinary($subjectHash),
                 'issuer'              => CertificateUtils::shortNameFromDN($certInfo['issuer']),
                 'issuer_hash'         => $dbTool->marshalBinary($issuerHash),
@@ -258,20 +279,16 @@ class CertificateUtils
 
         $certId = $db->lastInsertId();
 
-        CertificateUtils::insertSANs($db, $certId, $certInfo);
+        CertificateUtils::insertSANs($db, $certId, $sans);
 
         return [$certId, $issuerHash];
     }
 
-
-    private static function insertSANs($db, $certId, array $certInfo)
+    private static function insertSANs($db, $certId, iterable $sans): void
     {
         $dbTool = new DbTool($db);
-
-        if (isset($certInfo['extensions']['subjectAltName'])) {
-            foreach (CertificateUtils::splitSANs($certInfo['extensions']['subjectAltName']) as $san) {
-                list($type, $value) = $san;
-
+        foreach ($sans as $type => $values) {
+            foreach ($values as $value) {
                 $hash = hash('sha256', sprintf('%s=%s', $type, $value), true);
 
                 $row = X509CertificateSubjectAltName::on($db);
@@ -304,7 +321,6 @@ class CertificateUtils
         }
     }
 
-
     private static function findOrInsertDn($db, $certInfo, $type)
     {
         $dbTool = new DbTool($db);
@@ -320,7 +336,7 @@ class CertificateUtils
             }
 
             foreach ($values as $value) {
-                $data .= "{$key}=${value}, ";
+                $data .= "$key=$value, ";
             }
         }
         $hash = hash('sha256', $data, true);
@@ -432,7 +448,7 @@ class CertificateUtils
             ));
 
         $contents = [];
-
+        /** @var Model $ca */
         foreach ($cas as $ca) {
             $contents[] = $ca->certificate;
         }
@@ -444,52 +460,39 @@ class CertificateUtils
         $files->create($caFile, implode("\n", $contents));
 
         $count = 0;
+        $certs = X509Certificate::on($db)
+            ->with(['chain'])
+            ->utilize('chain.target')
+            ->columns(['chain.id', 'certificate'])
+            ->filter(Filter::equal('chain.valid', false))
+            ->orderBy('chain.id')
+            ->orderBy(new Expression('certificate_link.order'), SORT_DESC);
 
         $db->beginTransaction();
 
         try {
-            $chains = X509CertificateChain::on($db)->utilize('target');
-            $chains
-                ->columns(['id'])
-                ->filter(Filter::equal('valid', false));
-
-            foreach ($chains as $chain) {
-                ++$count;
-
-                $certs = X509Certificate::on($db)->utilize('chain');
-                $certs
-                    ->columns(['certificate'])
-                    ->filter(Filter::equal('chain.id', $chain->id))
-                    ->getSelectBase()
-                    ->orderBy('certificate_link.order', 'DESC');
-
-                $collection = [];
-
-                foreach ($certs as $cert) {
-                    $collection[] = $cert->certificate;
-                }
-
+            $caFile = escapeshellarg($files->resolvePath($caFile));
+            $verifyCertsFunc = function (int $chainId, array $collection) use ($db, $caFile) {
+                $certFiles = new TemporaryLocalFileStorage();
                 $certFile = uniqid('cert');
-
-                $files->create($certFile, array_pop($collection));
+                $certFiles->create($certFile, array_pop($collection));
 
                 $untrusted = '';
-
                 if (! empty($collection)) {
                     $intermediateFile = uniqid('intermediate');
-                    $files->create($intermediateFile, implode("\n", $collection));
+                    $certFiles->create($intermediateFile, implode("\n", $collection));
 
                     $untrusted = sprintf(
                         ' -untrusted %s',
-                        escapeshellarg($files->resolvePath($intermediateFile))
+                        escapeshellarg($certFiles->resolvePath($intermediateFile))
                     );
                 }
 
                 $command = sprintf(
                     'openssl verify -CAfile %s%s %s 2>&1',
-                    escapeshellarg($files->resolvePath($caFile)),
+                    $caFile,
                     $untrusted,
-                    escapeshellarg($files->resolvePath($certFile))
+                    escapeshellarg($certFiles->resolvePath($certFile))
                 );
 
                 $output = null;
@@ -504,18 +507,24 @@ class CertificateUtils
 
                 preg_match('/^error \d+ at \d+ depth lookup:(.+)$/m', $output, $match);
 
-                if (!empty($match)) {
+                if (! empty($match)) {
                     $set = ['invalid_reason' => trim($match[1])];
                 } else {
                     $set = ['valid' => 'y', 'invalid_reason' => null];
                 }
 
                 // TODO: https://github.com/Icinga/ipl-orm/pull/78
-                $db->update(
-                    'x509_certificate_chain',
-                    $set,
-                    ['id = ?' => $chain->id]
-                );
+                $db->update('x509_certificate_chain', $set, ['id = ?' => $chainId]);
+            };
+
+            $groupBy = function (X509Certificate $cert): array {
+                // Group all the certificates by their chain id.
+                return [$cert->chain->id, $cert->certificate];
+            };
+
+            foreach (yield_groups($certs, $groupBy) as $chainId => $collection) {
+                ++$count;
+                $verifyCertsFunc($chainId, $collection);
             }
 
             $db->commitTransaction();
